Index: sdk/lib/io/file.dart |
diff --git a/sdk/lib/io/file.dart b/sdk/lib/io/file.dart |
index e3be26bcf316c27095c1d9d64e23fe063eb81ceb..53a348c5033a68674a48480ccad6bb5849aee4cf 100644 |
--- a/sdk/lib/io/file.dart |
+++ b/sdk/lib/io/file.dart |
@@ -99,16 +99,16 @@ abstract class File { |
/** |
* Get the last-modified time of the file. Returns a |
* [:Future<Date>:] that completes with a [Date] object for the |
* modification date. |
*/ |
- Future<Date> lastModified(); |
+ Future<DateTime> lastModified(); |
/** |
* Get the last-modified time of the file. Throws an exception |
* if the file does not exist. |
*/ |
- Date lastModifiedSync(); |
+ DateTime lastModifiedSync(); |
/** |
* Open the file for random access operations. Returns a |
@@ -99,16 +99,16 @@ abstract class File { |
/** |
* Get the last-modified time of the file. Returns a |
- * [:Future<Date>:] that completes with a [Date] object for the |
+ * [:Future<DateTime>:] that completes with a [DateTime] object for the |
* modification date. |
*/ |